==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/es.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "The mountpoint name contains invalid characters." : "El punto de montaje contiene caracteres inválidos.",
    "Not allowed to create a federated share with the same user server" : "No se permite crear un recurso compartido federado con el mismo servidor de usuario",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido o no confiable",
    "Could not authenticate to remote share, password might be wrong" : "No se ha podido autenticar para compartir remotamente, quizás esté mal la contraseña",
    "Storage not valid" : "Almacenamiento inválido",
    "Couldn't add remote share" : "No se puede añadir un compartido remoto",
    "Shared with you" : "Compartido contigo",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por medio de enlaces",
    "Anonymous upload" : "Subida anónima",
    "Click to select files or use drag & drop to upload" : "Click Para seleccionar archivos o use arrastrar y soltar para subir",
    "Uploaded files" : "Archivos subidos",
    "Uploading..." : "Subiendo...",
    "Nothing shared with you yet" : "Todavía no han compartido nada contigo",
    "Files and folders others share with you will show up here" : "Aquí aparecerán archivos y carpetas que otros compartan contigo",
    "Nothing shared yet" : "Aún no hay nada compartido",
    "Files and folders you share will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta con otros",
    "No shared links" : "No hay enlaces compartidos",
    "Files and folders you share by link will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta mediante un enlace",
    "An error occurred while updating share state: {message}" : "Un error ha ocurrido mientras se trataba de actualizar el estado: {message}",
    "Accept Share" : "Aceptar compartido",
    "Decline Share" : "No aceptar compartido",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Recurso compartido remoto",
    "Remote share password" : "Contraseña del compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "You can upload into this folder" : "Usted puede cargar en esta carpeta",
    "No ownCloud installation (7 or higher) found at {remote}" : "No se encontró una instalación de ownCloud (7 o mayor) en {remote}",
    "Invalid ownCloud url" : "URL de ownCloud inválida",
    "Share" : "Compartir",
    "No expiration date set" : "No se ha establecido fecha de caducidad",
    "Declined" : "Denegado",
    "Pending" : "Pendiente",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartiendo",
    "A file or folder has been <strong>shared</strong>" : "Se ha <strong>compartido</strong> un archivo o carpeta",
    "A file or folder was shared from <strong>another server</strong>" : "Se ha compartido un archivo o carpeta desde <strong>otro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Se ha <strong>descargado</strong> un archivo o carpeta compartido públicamente",
    "You received a new remote share %2$s from %1$s" : "Recibió un nuevo recurso compartido remoto %2$s de %1$s",
    "You received a new remote share from %s" : "Ha recibido un nuevo recurso compartido remoto de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceptó el recurso compartido remoto %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rechazado el recurso compartido remoto %2$s",
    "%1$s unshared %2$s from you" : "%1$s dejó de compartirse %2$s por ti",
    "Public shared folder %1$s was downloaded" : "Se descargó la carpeta pública compartida %1$s",
    "Public shared file %1$s was downloaded" : "Se descargó el archivo público compartido %1$s",
    "You shared %1$s with %2$s" : "Usted compartió %1$s con %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartó %1$s con %3$s",
    "You removed the share of %2$s for %1$s" : "Ha cambiado el compartido %2$s por %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s eliminó la compartición de %3$s con %1$s",
    "You unshared %1$s shared by %2$s from self" : "Tú dejaste de compartir %1$s compartido por %2$s de sí mismo",
    "You shared %1$s with group %2$s" : "Usted ha compartido %1$s con el grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartió %1$s con el grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Ha cambiado el compartido del grupo %2$s por %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s ha cambiado el compartido del grupo %3$s por %1$s",
    "%2$s shared %1$s via link" : "%2$s compartió %1$s vía enlace",
    "You shared %1$s via link" : "Ha compartido %1$s vía enlace",
    "You removed the public link for %1$s" : "Ha borrado el enlace público de %1$s",
    "%2$s removed the public link for %1$s" : "%2$s ha eliminado el enlace público de %1$s",
    "Your public link for %1$s expired" : "Su enlace público %1$s ha expirado",
    "The public link of %2$s for %1$s expired" : "El enlace público de %2$s para %1$s ha expirado",
    "%2$s shared %1$s with you" : "%2$s ha compartido %1$s con usted",
    "%2$s removed the share for %1$s" : "%2$s ha borrado el compartido %1$s",
    "Downloaded via public link" : "Descargado vía enlace público",
    "Shared with %2$s" : "Compartido con %2$s",
    "Shared with %3$s by %2$s" : "Compartido con %3$s por %2$s",
    "Removed share for %2$s" : "Borrado el compartido %2$s",
    "%2$s removed share for %3$s" : "%2$s ha borrado el compartido %3$s",
    "Unshared %1$s from self" : "Dejó de compartirse  %1$s por ti",
    "Shared with group %2$s" : "Compartido con el grupo %2$s",
    "Shared with group %3$s by %2$s" : "Compartido con el grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Borrado el compartido del grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s ha borrado el compartido del grupo %3$s",
    "Shared via link by %2$s" : "Compartido vía enlace por %2$s",
    "Shared via public link" : "Compartido vía enlace público",
    "Removed public link" : "Eliminado enlace público",
    "%2$s removed public link" : "%2$s ha borrado el enlace público",
    "Public link expired" : "El enlace público ha expirado",
    "Public link of %2$s expired" : "El enlace público %2$s ha expirado",
    "Shared by %2$s" : "Compartido por %2$s",
    "Shares" : "Compartidos",
    "File sharing" : "Compartir Archivos",
    "Public link" : "Enlace Publico",
    "Couldn't send mail to following recipient(s): %s " : "No se puede enviar un correo electrónico a los siguientes receptores: %s ",
    "Share API is disabled" : "El API de compartir está deshabilitado",
    "Wrong share ID, share doesn't exist" : "El ID del recurso compartido no es correcto, el recurso compartido no existe",
    "Could not delete share" : "No se ha podido eliminar el recurso compartido",
    "Please specify a file or folder path" : "Por favor, especifica la ubicación de un archivo o carpeta",
    "Wrong path, file/folder doesn't exist" : "Ubicación incorrecta, el archivo/carpeta no existe",
    "Invalid date, date format must be YYYY-MM-DD" : "Fecha inválida, el formato de las fechas debe ser YYYY-MM-DD",
    "Please specify a valid user" : "Por favor, especifica un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupo está deshabilitado por el administrador",
    "Please specify a valid group" : "Por favor, especifica un grupo válido",
    "The group is blacklisted for sharing" : "El grupo está en la lista negra de compartir",
    "Public link sharing is disabled by the administrator" : "Compartir enlaces de forma pública está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "La subida pública está deshabilitado por el administrador",
    "Public upload is only possible for publicly shared folders" : "La subida publica solo es posible poara las carpetas publicas compartidas",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Compartir %s ha fallado porque el repositorio no admite compartidos del tipo %s",
    "Unknown share type" : "Tipo desconocido de recurso compartido",
    "Not a directory" : "No es un directorio",
    "Could not lock path" : "No se ha podido bloquear la ruta",
    "Could not update share" : "No se pudo actualizar la compartición",
    "Can't change permissions for public share links" : "No se pueden cambiar los permisos para los enlaces de recursos compartidos públicos",
    "Only recipient can change accepted state" : "Solo el receptor puede cambiar el cambio de estado.",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" ha compartido \"%3$s\" contigo (en nombre de \"%2$s\")",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" ha compartido \"%3$s\" contigo",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" te ha invitado a ver \"%3$s\" (en nombre de \"%2$s\")",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" te ha invitado a ver \"%3$s\"",
    "Accept" : "Aceptar",
    "Decline" : "Denegar",
    "Automatically accept new incoming local user shares" : "Aceptar automáticamente nuevos compartidos de los usuarios locales.",
    "This share is password-protected" : "Este elemento compartido está protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña introducida es errónea. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Name" : "Nombre",
    "State" : "Estado",
    "Share time" : "Compartido hace",
    "Expiration date" : "Fecha de caducidad",
    "Sorry, this link doesn’t seem to work anymore." : "Vaya, este enlace parece que no volverá a funcionar.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió el enlace.",
    "%s is publicly shared" : "%s esta compartido publicamente",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enlace directo",
    "Nothing to configure." : "Nada que configurar",
    "Group Sharing Blacklist" : "Lista negra Grupo compartidos",
    "Exclude groups from receiving shares" : "Excluir grupos de recibir compartidos",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Estos grupos no estarán disponibles para compartir. Los miembros de este grupo no están restringidos para compartir y pueden recibir compartidos respecto de otros grupos que sí son miembros."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.1.zip: owncloud/apps/files_sharing/l10n/es.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "The mountpoint name contains invalid characters." : "El punto de montaje contiene caracteres inválidos.",
    "Not allowed to create a federated share with the same user server" : "No se permite crear un recurso compartido federado con el mismo servidor de usuario",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido o no confiable",
    "Could not authenticate to remote share, password might be wrong" : "No se ha podido autenticar para compartir remotamente, quizás esté mal la contraseña",
    "Storage not valid" : "Almacenamiento inválido",
    "Couldn't add remote share" : "No se puede añadir un compartido remoto",
    "Shared with you" : "Compartido contigo",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por medio de enlaces",
    "Anonymous upload" : "Subida anónima",
    "Click to select files or use drag & drop to upload" : "Click Para seleccionar archivos o use arrastrar y soltar para subir",
    "Uploaded files" : "Archivos subidos",
    "Uploading..." : "Subiendo...",
    "Nothing shared with you yet" : "Todavía no han compartido nada contigo",
    "Files and folders others share with you will show up here" : "Aquí aparecerán archivos y carpetas que otros compartan contigo",
    "Nothing shared yet" : "Aún no hay nada compartido",
    "Files and folders you share will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta con otros",
    "No shared links" : "No hay enlaces compartidos",
    "Files and folders you share by link will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta mediante un enlace",
    "An error occurred while updating share state: {message}" : "Un error ha ocurrido mientras se trataba de actualizar el estado: {message}",
    "Accept Share" : "Aceptar compartido",
    "Decline Share" : "No aceptar compartido",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Recurso compartido remoto",
    "Remote share password" : "Contraseña del compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "You can upload into this folder" : "Usted puede cargar en esta carpeta",
    "No ownCloud installation (7 or higher) found at {remote}" : "No se encontró una instalación de ownCloud (7 o mayor) en {remote}",
    "Invalid ownCloud url" : "URL de ownCloud inválida",
    "Share" : "Compartir",
    "No expiration date set" : "No se ha establecido fecha de caducidad",
    "Declined" : "Denegado",
    "Pending" : "Pendiente",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartiendo",
    "A file or folder has been <strong>shared</strong>" : "Se ha <strong>compartido</strong> un archivo o carpeta",
    "A file or folder was shared from <strong>another server</strong>" : "Se ha compartido un archivo o carpeta desde <strong>otro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Se ha <strong>descargado</strong> un archivo o carpeta compartido públicamente",
    "You received a new remote share %2$s from %1$s" : "Recibió un nuevo recurso compartido remoto %2$s de %1$s",
    "You received a new remote share from %s" : "Ha recibido un nuevo recurso compartido remoto de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceptó el recurso compartido remoto %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rechazado el recurso compartido remoto %2$s",
    "%1$s unshared %2$s from you" : "%1$s dejó de compartirse %2$s por ti",
    "Public shared folder %1$s was downloaded" : "Se descargó la carpeta pública compartida %1$s",
    "Public shared file %1$s was downloaded" : "Se descargó el archivo público compartido %1$s",
    "You shared %1$s with %2$s" : "Usted compartió %1$s con %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartó %1$s con %3$s",
    "You removed the share of %2$s for %1$s" : "Ha cambiado el compartido %2$s por %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s eliminó la compartición de %3$s con %1$s",
    "You unshared %1$s shared by %2$s from self" : "Tú dejaste de compartir %1$s compartido por %2$s de sí mismo",
    "You shared %1$s with group %2$s" : "Usted ha compartido %1$s con el grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartió %1$s con el grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Ha cambiado el compartido del grupo %2$s por %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s ha cambiado el compartido del grupo %3$s por %1$s",
    "%2$s shared %1$s via link" : "%2$s compartió %1$s vía enlace",
    "You shared %1$s via link" : "Ha compartido %1$s vía enlace",
    "You removed the public link for %1$s" : "Ha borrado el enlace público de %1$s",
    "%2$s removed the public link for %1$s" : "%2$s ha eliminado el enlace público de %1$s",
    "Your public link for %1$s expired" : "Su enlace público %1$s ha expirado",
    "The public link of %2$s for %1$s expired" : "El enlace público de %2$s para %1$s ha expirado",
    "%2$s shared %1$s with you" : "%2$s ha compartido %1$s con usted",
    "%2$s removed the share for %1$s" : "%2$s ha borrado el compartido %1$s",
    "Downloaded via public link" : "Descargado vía enlace público",
    "Shared with %2$s" : "Compartido con %2$s",
    "Shared with %3$s by %2$s" : "Compartido con %3$s por %2$s",
    "Removed share for %2$s" : "Borrado el compartido %2$s",
    "%2$s removed share for %3$s" : "%2$s ha borrado el compartido %3$s",
    "Unshared %1$s from self" : "Dejó de compartirse  %1$s por ti",
    "Shared with group %2$s" : "Compartido con el grupo %2$s",
    "Shared with group %3$s by %2$s" : "Compartido con el grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Borrado el compartido del grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s ha borrado el compartido del grupo %3$s",
    "Shared via link by %2$s" : "Compartido vía enlace por %2$s",
    "Shared via public link" : "Compartido vía enlace público",
    "Removed public link" : "Eliminado enlace público",
    "%2$s removed public link" : "%2$s ha borrado el enlace público",
    "Public link expired" : "El enlace público ha expirado",
    "Public link of %2$s expired" : "El enlace público %2$s ha expirado",
    "Shared by %2$s" : "Compartido por %2$s",
    "Shares" : "Compartidos",
    "File sharing" : "Compartir Archivos",
    "Public link" : "Enlace Publico",
    "Couldn't send mail to following recipient(s): %s " : "No se puede enviar un correo electrónico a los siguientes receptores: %s ",
    "Share API is disabled" : "El API de compartir está deshabilitado",
    "Wrong share ID, share doesn't exist" : "El ID del recurso compartido no es correcto, el recurso compartido no existe",
    "Could not delete share" : "No se ha podido eliminar el recurso compartido",
    "Please specify a file or folder path" : "Por favor, especifica la ubicación de un archivo o carpeta",
    "Wrong path, file/folder doesn't exist" : "Ubicación incorrecta, el archivo/carpeta no existe",
    "Invalid date, date format must be YYYY-MM-DD" : "Fecha inválida, el formato de las fechas debe ser YYYY-MM-DD",
    "Please specify a valid user" : "Por favor, especifica un usuario válido",
    "Group sharing is disabled by the administrator" : "Compartir en grupo está deshabilitado por el administrador",
    "Please specify a valid group" : "Por favor, especifica un grupo válido",
    "The group is blacklisted for sharing" : "El grupo está en la lista negra de compartir",
    "Public link sharing is disabled by the administrator" : "Compartir enlaces de forma pública está deshabilitado por el administrador",
    "Public upload disabled by the administrator" : "La subida pública está deshabilitado por el administrador",
    "Public upload is only possible for publicly shared folders" : "La subida publica solo es posible poara las carpetas publicas compartidas",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Compartir %s ha fallado porque el repositorio no admite compartidos del tipo %s",
    "Unknown share type" : "Tipo desconocido de recurso compartido",
    "Not a directory" : "No es un directorio",
    "Could not lock path" : "No se ha podido bloquear la ruta",
    "Could not update share" : "No se pudo actualizar la compartición",
    "Can't change permissions for public share links" : "No se pueden cambiar los permisos para los enlaces de recursos compartidos públicos",
    "Only recipient can change accepted state" : "Solo el receptor puede cambiar el cambio de estado.",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" ha compartido \"%3$s\" contigo (en nombre de \"%2$s\")",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" ha compartido \"%3$s\" contigo",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" te ha invitado a ver \"%3$s\" (en nombre de \"%2$s\")",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" te ha invitado a ver \"%3$s\"",
    "Accept" : "Aceptar",
    "Decline" : "Denegar",
    "Automatically accept new incoming local user shares" : "Aceptar automáticamente nuevos compartidos de los usuarios locales.",
    "Allow finding you via autocomplete in share dialog. If this is disabled the full username needs to be entered." : "Permite que lo encuentren a través del completado automático en un diálogo de compartición. Si esta opción está deshabilitada es necesario introducir el nombre de usuario completo.",
    "This share is password-protected" : "Este elemento compartido está protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña introducida es errónea. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Name" : "Nombre",
    "State" : "Estado",
    "Share time" : "Compartido hace",
    "Expiration date" : "Fecha de caducidad",
    "Sorry, this link doesn’t seem to work anymore." : "Vaya, este enlace parece que no volverá a funcionar.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió el enlace.",
    "%s is publicly shared" : "%s esta compartido publicamente",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enlace directo",
    "Nothing to configure." : "Nada que configurar",
    "Group Sharing Blacklist" : "Lista negra Grupo compartidos",
    "Exclude groups from receiving shares" : "Excluir grupos de recibir compartidos",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Estos grupos no estarán disponibles para compartir. Los miembros de este grupo no están restringidos para compartir y pueden recibir compartidos respecto de otros grupos que sí son miembros."
},
"nplurals=2; plural=(n != 1);");
